==> commons-jvm-3.0.0-sources.jar: commonMain/pro/flashup/repositories/users/UsersRemoteRepository.kt <==
package pro.flashup.repositories.users

import dev.kaccelero.models.RecursiveId
import dev.kaccelero.models.UUID
import dev.kaccelero.models.UnitModel
import dev.kaccelero.repositories.APIModelRemoteRepository
import io.ktor.client.call.*
import io.ktor.client.request.*
import io.ktor.http.*
import io.ktor.util.reflect.*
import pro.flashup.client.IFlashUpClient
import pro.flashup.models.folders.UpdateUserFoldersPayload
import pro.flashup.models.folders.UserFolder
import pro.flashup.models.users.CreateUserPayload
import pro.flashup.models.users.UpdateUserPayload
import pro.flashup.models.users.User

class UsersRemoteRepository(
    client: IFlashUpClient,
) : APIModelRemoteRepository<User, UUID, CreateUserPayload, UpdateUserPayload>(
    typeInfo<User>(),
    typeInfo<CreateUserPayload>(),
    typeInfo<UpdateUserPayload>(),
    typeInfo<List<User>>(),
    client,
    prefix = "/api/v1"
), IUsersRemoteRepository {

    override suspend fun get(id: UUID): User? = get(id, null)

    override suspend fun update(id: UUID, payload: UpdateUserPayload): User? =
        update(id, payload, null)

    override suspend fun listFolders(id: UUID): List<UserFolder> = client.request(
        HttpMethod.Get,
        "${constructFullRoute(RecursiveId<UnitModel, Unit, Unit>(Unit))}/$id/folders"
    ).body()

    override suspend fun updateFolders(id: UUID, payload: UpdateUserFoldersPayload) = client.request(
        HttpMethod.Post,
        "${constructFullRoute(RecursiveId<UnitModel, Unit, Unit>(Unit))}/$id/folders"
    ) {
        contentType(ContentType.Application.Json)
        setBody(payload)
    }.let {}

}

==> commons-jvm-3.0.3-sources.jar: commonMain/pro/flashup/repositories/users/UsersRemoteRepository.kt <==
package pro.flashup.repositories.users

import dev.kaccelero.models.RecursiveId
import dev.kaccelero.models.UUID
import dev.kaccelero.models.UnitModel
import dev.kaccelero.repositories.APIModelRemoteRepository
import io.ktor.client.call.*
import io.ktor.client.request.*
import io.ktor.http.*
import io.ktor.util.reflect.*
import pro.flashup.client.IFlashUpClient
import pro.flashup.models.folders.UpdateUserFoldersPayload
import pro.flashup.models.folders.UserFolder
import pro.flashup.models.users.CreateUserPayload
import pro.flashup.models.users.UpdateUserPayload
import pro.flashup.models.users.User

class UsersRemoteRepository(
    client: IFlashUpClient,
) : APIModelRemoteRepository<User, UUID, CreateUserPayload, UpdateUserPayload>(
    typeInfo<User>(),
    typeInfo<CreateUserPayload>(),
    typeInfo<UpdateUserPayload>(),
    typeInfo<List<User>>(),
    client,
    prefix = "/api/v1"
), IUsersRemoteRepository {

    override suspend fun get(id: UUID): User? = get(id, null)

    override suspend fun update(id: UUID, payload: UpdateUserPayload): User? =
        update(id, payload, null)

    override suspend fun listFolders(id: UUID, includeDeleted: Boolean): List<UserFolder> = client.request(
        HttpMethod.Get,
        "${constructFullRoute(RecursiveId<UnitModel, Unit, Unit>(Unit))}/$id/folders"
    ) {
        parameter("includeDeleted", includeDeleted)
    }.body()

    override suspend fun updateFolders(id: UUID, payload: UpdateUserFoldersPayload) = client.request(
        HttpMethod.Post,
        "${constructFullRoute(RecursiveId<UnitModel, Unit, Unit>(Unit))}/$id/folders"
    ) {
        contentType(ContentType.Application.Json)
        setBody(payload)
    }.let {}

}
